@@ -89,21 +89,14 @@ This module is free software; you can redistribute it and/or modify it under the
 
 =cut
 
-
 package CGI::Application::Plugin::PageBuilder;
-$VERSION = '0.9';
-
-use Carp;
+our $VERSION = "0.91";
+use strict;
 
 use base 'Exporter';
 use vars '@EXPORT';
 
-@EXPORT = qw(
-			 pb_init
-			 pb_template
-			 pb_param
-			 pb_build
-			);
+@EXPORT = qw( pb_template pb_param pb_build );
 
 sub pb_template {
 	my( $self, $template, %options ) = @_;
